pm4py.algo.conformance.log\_skeleton package
============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.log_skeleton.variants

Submodules
----------

pm4py.algo.conformance.log\_skeleton.algorithm module
-----------------------------------------------------

.. automodule:: pm4py.algo.conformance.log_skeleton.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.log\_skeleton.outputs module
---------------------------------------------------

.. automodule:: pm4py.algo.conformance.log_skeleton.outputs
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.log_skeleton
   :members:
   :undoc-members:
   :show-inheritance:
